@@ -83,5 +83,10 @@ from .ztime import get_month
 
 
 # zalioss
+from .zalioss import AliOss
 from .zalioss import OssConfig
-from .zalioss import OssFile
+from .zalioss import oss_connect
+
+
+# zexcel
+from .zexcel import trans_excel_to_csv
