@@ -1,22 +1,43 @@
+import re
+import oss2
+
+__OSS_URL_KEY = "OSS_URL"
+
+
 class OssConfig:
-    def __init__(self, access_key_id='', access_key_secret='', bucket='', endpoint=''):
+    def __init__(self, url):
+        result = re.search("^(oss://){0,1}([^/]+)/([^?]+)\?(.*)$", url)
+        groups = result.groups()
+        endpoint = f"https://{groups[1]}"
+        assert endpoint
+        bucket = groups[2]
+        assert bucket
+        param = dict([it.split('=')
+                      for it in groups[3].split('&')])
+        assert param
+        access_key_id = param.get("key")
+        assert access_key_id
+        access_key_secret = param.get("secret")
+        assert access_key_secret
+        
         self.access_key_id = access_key_id
         self.access_key_secret = access_key_secret
         self.bucket = bucket
         self.endpoint = endpoint
 
 
-class OssFile:
-    def __init__(self, config=None):
-        import oss2
-        if not config:
-            from .zconfig import get_param
-            config = OssConfig()
-            config.access_key_id = get_param("OSS_ACCESS_KEY_ID", default_value='')
-            config.access_key_secret = get_param(
-                "OSS_ACCESS_KEY_SECRET", default_value='')
-            config.bucket = get_param("OSS_BUCKET", default_value='')
-            config.endpoint = get_param("OSS_ENDPOINT", default_value='')
+def oss_connect(url=None):
+    if not url:
+        from .zconfig import get_param
+        url = get_param(__OSS_URL_KEY)
+    assert url
+
+    return AliOss(url)
+
+
+class AliOss:
+    def __init__(self, url):
+        config = OssConfig(url)
         self.bucket = oss2.Bucket(
             oss2.Auth(config.access_key_id, config.access_key_secret), config.endpoint, config.bucket)
 
